@@ -8,6 +8,9 @@ from __future__ import (
     annotations,
 )
 
+from inspect import (
+    isawaitable,
+)
 from typing import (
     Any,
     NoReturn,
@@ -29,6 +32,9 @@ from ..abc import (
 from ..entries import (
     HandlerEntry,
 )
+from .messages import (
+    CommandRequest,
+)
 
 
 class CommandHandler(Handler):
@@ -56,7 +62,11 @@ class CommandHandler(Handler):
         command: Command = row.data
         definition_id = command.saga_uuid
 
-        response = await row.callback(row.topic, command)
+        request = CommandRequest(command)
+        response = row.callback(request)
+        if isawaitable(response):
+            response = await response
 
         if command.reply_topic is not None:
-            await self.broker.send(response, topic=command.reply_topic, saga_uuid=definition_id)
+            items = await response.content()
+            await self.broker.send(items, topic=command.reply_topic, saga_uuid=definition_id)
