@@ -4,6 +4,10 @@
 #
 # Minos framework can not be copied and/or distributed without the express
 # permission of Clariteia SL.
+from __future__ import (
+    annotations,
+)
+
 from typing import (
     Any,
     NoReturn,
@@ -25,11 +29,15 @@ from ..entries import (
 class EventHandler(Handler):
     """Event Handler class."""
 
-    TABLE = "event_queue"
+    TABLE_NAME = "event_queue"
 
-    def __init__(self, *, config: MinosConfig, **kwargs: Any):
-        super().__init__(table_name=self.TABLE, config=config.events, **kwargs)
-        self._broker_group_name = f"event_{config.service.name}"
+    def __init__(self, *, service_name: str, **kwargs: Any):
+        super().__init__(broker_group_name=f"event_{service_name}", **kwargs)
+
+    @classmethod
+    def _from_config(cls, *args, config: MinosConfig, **kwargs) -> EventHandler:
+        handlers = {item.name: {"controller": item.controller, "action": item.action} for item in config.events.items}
+        return cls(service_name=config.service.name, handlers=handlers, **config.events.queue._asdict(), **kwargs)
 
     def _build_data(self, value: bytes) -> Event:
         return Event.from_avro_bytes(value)
